@@ -10,11 +10,12 @@
 
 import matplotlib
 import matplotlib.pyplot as plt
+import numpy as np
 from mpl_toolkits.mplot3d import Axes3D
 from mpl_toolkits.axes_grid1 import make_axes_locatable
 from numpy import (array, asarray, cos, exp, linspace, matrix, meshgrid,
                    ndarray, ones, outer, real, remainder, sin, size, sqrt,
-                   zeros_like, mean)
+                   zeros_like)
 from scipy.signal import fftconvolve
 
 from . import np, degrees, eps
@@ -60,7 +61,7 @@ linestyles = [('dashdot', 'dashdot'),
 #     return id_fig, IDax, IDimage
 
 
-def draw_empty_sphere(ax, angle_view):
+def draw_empty_sphere(ax, angle_view, axis_equal=True):
     """Fucntion that plots an empty Poincare sphere.
     """
 
@@ -171,7 +172,8 @@ def draw_empty_sphere(ax, angle_view):
 
     plt.tight_layout()
     # set_aspect_equal_3d(ax)
-    ax.set_aspect('equal')
+    if axis_equal:
+        ax.set_aspect('equal')
 
 
 def draw_poincare(S,
@@ -183,7 +185,8 @@ def draw_poincare(S,
                   angle_view=[0.5, -1],
                   figsize=(6, 6),
                   filename='',
-                  subplots=None):
+                  subplots=None,
+                  axis_equal=True):
     """Function to draw the poincare sphere.
     It admits Stokes or a list with Stokes, or None
 
@@ -195,6 +198,7 @@ def draw_poincare(S,
         color (str): color of line or scatter.
         label (str): labels for drawing.
         filename (str): name of filename to save the figure.
+        axis_equal (bool): If True, the axis_equal method is used. Default: True.
     """
     # Calculate the number of subplots
     if subplots is None:
